@@ -88,7 +88,7 @@ class InstanceTypeAttributes(IntFlag):
     NAMING_CONTEXT_BEING_REMOVED_FROM_LOCAL_DSA                 = 0x00000020  # 32
 
 
-class CommonQueries(Enum):
+class CommonQueries(str, Enum):
 
     # https://social.technet.microsoft.com/wiki/contents/articles/5392.active-directory-ldap-syntax-filters.aspx
 
